Module prelude

Module prelude 

Structs

ApiClient
The wrapper around an api definition that handles building and making requests correctly. Internally stores a copy of the current reqwest client, the global config, and the api interface to use. Can be safely sent across threads thanks to reqwest’s internal architecture. Note that interfaces impl Send + Sync by default as well.

Traits

ApiInterface
The public interface used to access any api. Should be implemented to provide specific details about how to make a given api call.